# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmAccessToken(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'edges': 'OrmAccessTokenEdges',
        'experiment_id': 'int',
        'expire_at': 'datetime',
        'id': 'int',
        'immutable_slug': 'str',
        'permissions': 'dict[str, object]',
        'pipeline_step_execution_id': 'int',
        'service_id': 'int',
        'title': 'str',
        'type': 'str',
        'updated_dt': 'datetime',
        'user_id': 'int',
        'workspace_id': 'int'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'edges': 'edges',
        'experiment_id': 'experiment_id',
        'expire_at': 'expire_at',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'permissions': 'permissions',
        'pipeline_step_execution_id': 'pipeline_step_execution_id',
        'service_id': 'service_id',
        'title': 'title',
        'type': 'type',
        'updated_dt': 'updated_dt',
        'user_id': 'user_id',
        'workspace_id': 'workspace_id'
    }

    def __init__(self, created_dt=None, edges=None, experiment_id=None, expire_at=None, id=None, immutable_slug=None, permissions=None, pipeline_step_execution_id=None, service_id=None, title=None, type=None, updated_dt=None, user_id=None, workspace_id=None, local_vars_configuration=None):  # noqa: E501
        """OrmAccessToken - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._edges = None
        self._experiment_id = None
        self._expire_at = None
        self._id = None
        self._immutable_slug = None
        self._permissions = None
        self._pipeline_step_execution_id = None
        self._service_id = None
        self._title = None
        self._type = None
        self._updated_dt = None
        self._user_id = None
        self._workspace_id = None
        self.discriminator = None

        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        self.experiment_id = experiment_id
        self.expire_at = expire_at
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if permissions is not None:
            self.permissions = permissions
        self.pipeline_step_execution_id = pipeline_step_execution_id
        self.service_id = service_id
        self.title = title
        if type is not None:
            self.type = type
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.user_id = user_id
        self.workspace_id = workspace_id

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmAccessToken.  # noqa: E501


        :return: The created_dt of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmAccessToken.


        :param created_dt: The created_dt of this OrmAccessToken.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmAccessToken.  # noqa: E501


        :return: The edges of this OrmAccessToken.  # noqa: E501
        :rtype: OrmAccessTokenEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmAccessToken.


        :param edges: The edges of this OrmAccessToken.  # noqa: E501
        :type edges: OrmAccessTokenEdges
        """

        self._edges = edges

    @property
    def experiment_id(self):
        """Gets the experiment_id of this OrmAccessToken.  # noqa: E501


        :return: The experiment_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this OrmAccessToken.


        :param experiment_id: The experiment_id of this OrmAccessToken.  # noqa: E501
        :type experiment_id: int
        """

        self._experiment_id = experiment_id

    @property
    def expire_at(self):
        """Gets the expire_at of this OrmAccessToken.  # noqa: E501


        :return: The expire_at of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._expire_at

    @expire_at.setter
    def expire_at(self, expire_at):
        """Sets the expire_at of this OrmAccessToken.


        :param expire_at: The expire_at of this OrmAccessToken.  # noqa: E501
        :type expire_at: datetime
        """

        self._expire_at = expire_at

    @property
    def id(self):
        """Gets the id of this OrmAccessToken.  # noqa: E501


        :return: The id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmAccessToken.


        :param id: The id of this OrmAccessToken.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmAccessToken.  # noqa: E501


        :return: The immutable_slug of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmAccessToken.


        :param immutable_slug: The immutable_slug of this OrmAccessToken.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def permissions(self):
        """Gets the permissions of this OrmAccessToken.  # noqa: E501


        :return: The permissions of this OrmAccessToken.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this OrmAccessToken.


        :param permissions: The permissions of this OrmAccessToken.  # noqa: E501
        :type permissions: dict[str, object]
        """

        self._permissions = permissions

    @property
    def pipeline_step_execution_id(self):
        """Gets the pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501


        :return: The pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_step_execution_id

    @pipeline_step_execution_id.setter
    def pipeline_step_execution_id(self, pipeline_step_execution_id):
        """Sets the pipeline_step_execution_id of this OrmAccessToken.


        :param pipeline_step_execution_id: The pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501
        :type pipeline_step_execution_id: int
        """

        self._pipeline_step_execution_id = pipeline_step_execution_id

    @property
    def service_id(self):
        """Gets the service_id of this OrmAccessToken.  # noqa: E501


        :return: The service_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this OrmAccessToken.


        :param service_id: The service_id of this OrmAccessToken.  # noqa: E501
        :type service_id: int
        """

        self._service_id = service_id

    @property
    def title(self):
        """Gets the title of this OrmAccessToken.  # noqa: E501


        :return: The title of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this OrmAccessToken.


        :param title: The title of this OrmAccessToken.  # noqa: E501
        :type title: str
        """

        self._title = title

    @property
    def type(self):
        """Gets the type of this OrmAccessToken.  # noqa: E501


        :return: The type of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmAccessToken.


        :param type: The type of this OrmAccessToken.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmAccessToken.  # noqa: E501


        :return: The updated_dt of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmAccessToken.


        :param updated_dt: The updated_dt of this OrmAccessToken.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def user_id(self):
        """Gets the user_id of this OrmAccessToken.  # noqa: E501


        :return: The user_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this OrmAccessToken.


        :param user_id: The user_id of this OrmAccessToken.  # noqa: E501
        :type user_id: int
        """

        self._user_id = user_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this OrmAccessToken.  # noqa: E501


        :return: The workspace_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this OrmAccessToken.


        :param workspace_id: The workspace_id of this OrmAccessToken.  # noqa: E501
        :type workspace_id: int
        """

        self._workspace_id = workspace_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmAccessToken):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmAccessToken):
            return True

        return self.to_dict() != other.to_dict()
